@@ -1,5 +1,5 @@
 package Util::Medley;
-$Util::Medley::VERSION = '0.054';
+$Util::Medley::VERSION = '0.055';
 use Modern::Perl;
 use Moose;
 
@@ -11,8 +11,6 @@ with
   'Util::Medley::Roles::Attributes::File::Zip',
   'Util::Medley::Roles::Attributes::Hash',
   'Util::Medley::Roles::Attributes::Hostname',
-  'Util::Medley::Roles::Attributes::Linux::PkgMgmt::RPM',
-  'Util::Medley::Roles::Attributes::Linux::PkgMgmt::YUM',
   'Util::Medley::Roles::Attributes::List',
   'Util::Medley::Roles::Attributes::Logger',
   'Util::Medley::Roles::Attributes::Spawn',
@@ -25,7 +23,7 @@ Util::Medley - A collection of commonly used utilities.
 
 =head1 VERSION
 
-version 0.054
+version 0.055
 
 =head1 SYNOPSIS
 
@@ -68,10 +66,6 @@ interface to commonly used modules all under one roof.
 
 =item L<Util::Medley::File::Zip>
 
-=item L<Util::Medley::Linux::PkgMgmt::RPM>
-
-=item L<Util::Medley::Linux::PkgMgmt::YUM>
-
 =item L<Util::Medley::List>
 
 =item L<Util::Medley::Logger>
